@@ -33,6 +33,7 @@ from ultimate_notion.blocks import (
 from ultimate_notion.blocks import (
     Quote as UnoQuote,
 )
+from ultimate_notion.blocks import Table as UnoTable
 from ultimate_notion.blocks import (
     TableOfContents as UnoTableOfContents,
 )
@@ -41,7 +42,7 @@ from ultimate_notion.blocks import (
 )
 from ultimate_notion.core import NotionObject
 from ultimate_notion.obj_api.core import GenericObject
-from ultimate_notion.obj_api.enums import CodeLang, Color
+from ultimate_notion.obj_api.enums import BGColor, CodeLang
 from ultimate_notion.rich_text import Text, text
 
 
@@ -77,8 +78,12 @@ def _process_list_item_recursively(node: nodes.list_item) -> UnoBulletedItem:
 
 
 def _create_rich_text_from_children(*, node: nodes.Element) -> Text:
-    """
-    Create Notion rich text from ``docutils`` node children.
+    """Create Notion rich text from ``docutils`` node children.
+
+    This uses ``ultimate-notion``'s rich text capabilities to
+    avoid some size limits.
+
+    See: https://developers.notion.com/reference/request-limits#size-limits.
     """
     rich_text = Text.from_plain_text(text="")
 
@@ -108,6 +113,58 @@ def _create_rich_text_from_children(*, node: nodes.Element) -> Text:
     return rich_text
 
 
+def _extract_table_structure(
+    node: nodes.table,
+) -> tuple[int, nodes.row | None, list[nodes.row]]:
+    """
+    Return (n_cols, header_row, body_rows) for a table node.
+    """
+    header_row = None
+    body_rows: list[nodes.row] = []
+    n_cols = 0
+
+    for child in node.children:
+        assert isinstance(child, nodes.tgroup)
+        n_cols = int(child.get(key="cols", failobj=0))
+        for tgroup_child in child.children:
+            if isinstance(tgroup_child, nodes.thead):
+                for row in tgroup_child.children:
+                    assert isinstance(row, nodes.row)
+                    header_row = row
+            elif isinstance(tgroup_child, nodes.tbody):
+                for row in tgroup_child.children:
+                    assert isinstance(row, nodes.row)
+                    body_rows.append(row)
+
+    return n_cols, header_row, body_rows
+
+
+def _cell_source_node(entry: nodes.Node) -> nodes.paragraph:
+    """Return the paragraph child of an entry if present, else the entry.
+
+    This isolates the small branch used when converting a table cell so
+    the main table function becomes simpler.
+    """
+    paragraph_children = [
+        c for c in entry.children if isinstance(c, nodes.paragraph)
+    ]
+    if len(paragraph_children) == 1:
+        return paragraph_children[0]
+
+    # If there are multiple children (multiple paragraphs or mixed nodes),
+    # create a combined node that preserves all content. We insert a
+    # double-newline text node between each top-level child to mimic
+    # paragraph separation when converting to plain text/rich text.
+    # Join the plain text of each top-level child with two newlines so
+    # the resulting rich text becomes a single text fragment like
+    # 'Cell 3\n\nCell 3' (matches test expectations).
+    parts: list[str] = [c.astext() for c in entry.children]
+    joined = "\n\n".join(parts)
+    combined = nodes.paragraph()
+    combined += nodes.Text(data=joined)
+    return combined
+
+
 @singledispatch
 def _process_node_to_blocks(
     node: nodes.Element,
@@ -117,9 +174,42 @@ def _process_node_to_blocks(
     """
     Required function for ``singledispatch``.
     """
-    del node
     del section_level
-    raise NotImplementedError
+    raise NotImplementedError(node)
+
+
+@_process_node_to_blocks.register
+def _(node: nodes.table, *, section_level: int) -> list[NotionObject[Any]]:
+    """Process rST table nodes by creating Notion Table blocks.
+
+    This implementation delegates small branches to helpers which keeps
+    the function body linear and easier to reason about.
+    """
+    del section_level
+
+    n_cols, header_row, body_rows = _extract_table_structure(node=node)
+
+    n_rows = 1 + len(body_rows) if header_row else len(body_rows)
+    table = UnoTable(n_rows=n_rows, n_cols=n_cols, header_row=bool(header_row))
+
+    row_idx = 0
+    if header_row is not None:
+        for col_idx, entry in enumerate(iterable=header_row.children):
+            source = _cell_source_node(entry=entry)
+            table[row_idx, col_idx] = _create_rich_text_from_children(
+                node=source
+            )
+        row_idx += 1
+
+    for body_row in body_rows:
+        for col_idx, entry in enumerate(iterable=body_row.children):
+            source = _cell_source_node(entry=entry)
+            table[row_idx, col_idx] = _create_rich_text_from_children(
+                node=source
+            )
+        row_idx += 1
+
+    return [table]
 
 
 @_process_node_to_blocks.register
@@ -165,7 +255,8 @@ def _(
     # By default, the code block has a color set (DEFAULT) which means
     # that there is no syntax highlighting.
     # See https://github.com/ultimate-notion/ultimate-notion/issues/93.
-    del code_text.rich_texts[0].obj_ref.annotations  # pyright: ignore[reportUnknownMemberType]
+    for rich_text in code_text.rich_texts:  # pyright: ignore[reportUnknownMemberType, reportUnknownVariableType]
+        del rich_text.obj_ref.annotations  # pyright: ignore[reportUnknownMemberType]
     code_block.rich_text = code_text
     return [code_block]
 
@@ -199,6 +290,19 @@ def _(node: nodes.topic, *, section_level: int) -> list[NotionObject[Any]]:
     return [UnoTableOfContents()]
 
 
+@_process_node_to_blocks.register
+def _(node: nodes.compound, *, section_level: int) -> list[NotionObject[Any]]:
+    """
+    Process Sphinx ``toctree`` nodes.
+    """
+    del node
+    del section_level
+    # There are no specific Notion blocks for ``toctree`` nodes.
+    # We need to support ``toctree`` in ``index.rst``.
+    # Just ignore it.
+    return []
+
+
 @_process_node_to_blocks.register
 def _(node: nodes.title, *, section_level: int) -> list[NotionObject[Any]]:
     """
@@ -222,14 +326,16 @@ def _create_admonition_callout(
     node: nodes.Element,
     *,
     emoji: str,
-    color: Color,
+    background_color: BGColor,
 ) -> list[NotionObject[Any]]:
     """Create a Notion Callout block for admonition nodes.
 
     The first child (typically a paragraph) becomes the callout text,
     and any remaining children become nested blocks within the callout.
     """
-    block = UnoCallout(text="", icon=Emoji(emoji=emoji), color=color)
+    block = UnoCallout(
+        text="", icon=Emoji(emoji=emoji), color=background_color
+    )
 
     # Use the first child as the callout text
     first_child = node.children[0]
@@ -266,7 +372,11 @@ def _(node: nodes.note, *, section_level: int) -> list[NotionObject[Any]]:
     Process note admonition nodes by creating Notion Callout blocks.
     """
     del section_level
-    return _create_admonition_callout(node=node, emoji="📝", color=Color.BLUE)
+    return _create_admonition_callout(
+        node=node,
+        emoji="📝",
+        background_color=BGColor.BLUE,
+    )
 
 
 @_process_node_to_blocks.register
@@ -275,7 +385,11 @@ def _(node: nodes.warning, *, section_level: int) -> list[NotionObject[Any]]:
     Process warning admonition nodes by creating Notion Callout blocks.
     """
     del section_level
-    return _create_admonition_callout(node=node, emoji="⚠️", color=Color.YELLOW)
+    return _create_admonition_callout(
+        node=node,
+        emoji="⚠️",
+        background_color=BGColor.YELLOW,
+    )
 
 
 @_process_node_to_blocks.register
@@ -284,7 +398,11 @@ def _(node: nodes.tip, *, section_level: int) -> list[NotionObject[Any]]:
     Process tip admonition nodes by creating Notion Callout blocks.
     """
     del section_level
-    return _create_admonition_callout(node=node, emoji="💡", color=Color.GREEN)
+    return _create_admonition_callout(
+        node=node,
+        emoji="💡",
+        background_color=BGColor.GREEN,
+    )
 
 
 @_process_node_to_blocks.register
@@ -549,6 +667,30 @@ class NotionTranslator(NodeVisitor):
 
         raise nodes.SkipNode
 
+    def visit_table(self, node: nodes.Element) -> None:
+        """
+        Handle table nodes by creating Notion Table blocks.
+        """
+        blocks = _process_node_to_blocks(
+            node,
+            section_level=self._section_level,
+        )
+        self._blocks.extend(blocks)
+
+        raise nodes.SkipNode
+
+    def visit_compound(self, node: nodes.Element) -> None:
+        """
+        Handle compound admonition nodes by creating a table of contents block.
+        """
+        blocks = _process_node_to_blocks(
+            node,
+            section_level=self._section_level,
+        )
+        self._blocks.extend(blocks)
+
+        raise nodes.SkipNode
+
     def visit_CollapseNode(self, node: nodes.Element) -> None:  # pylint: disable=invalid-name  # noqa: N802
         """
         Handle collapse nodes by creating Notion ToggleItem blocks.
