@@ -29,6 +29,7 @@ from ultimate_notion.blocks import (
 from ultimate_notion.blocks import (
     Quote as UnoQuote,
 )
+from ultimate_notion.blocks import Table as UnoTable
 from ultimate_notion.blocks import (
     TableOfContents as UnoTableOfContents,
 )
@@ -37,7 +38,7 @@ from ultimate_notion.blocks import (
 )
 from ultimate_notion.core import NotionObject
 from ultimate_notion.obj_api.core import GenericObject
-from ultimate_notion.obj_api.enums import CodeLang, Color
+from ultimate_notion.obj_api.enums import BGColor, CodeLang
 from ultimate_notion.rich_text import text
 
 
@@ -573,6 +574,32 @@ def test_table_of_contents(
     )
 
 
+def test_toctree_directive(
+    make_app: Callable[..., SphinxTestApp],
+    tmp_path: Path,
+) -> None:
+    """
+    Test that the ``toctree`` directive converts to nothing.
+    """
+    rst_content = """
+        Introduction
+        ============
+
+        .. toctree::
+    """
+
+    expected_objects: list[NotionObject[Any]] = [
+        UnoHeading1(text="Introduction"),
+    ]
+
+    _assert_rst_converts_to_notion_objects(
+        rst_content=rst_content,
+        expected_objects=expected_objects,
+        make_app=make_app,
+        tmp_path=tmp_path,
+    )
+
+
 def test_simple_code_block(
     make_app: Callable[..., SphinxTestApp],
     tmp_path: Path,
@@ -714,18 +741,18 @@ def test_bullet_list_with_inline_formatting(
 
 
 @pytest.mark.parametrize(
-    argnames=("admonition_type", "emoji", "color", "message"),
+    argnames=("admonition_type", "emoji", "background_color", "message"),
     argvalues=[
-        ("note", "📝", Color.BLUE, "This is an important note."),
-        ("warning", "⚠️", Color.YELLOW, "This is a warning message."),
-        ("tip", "💡", Color.GREEN, "This is a helpful tip."),
+        ("note", "📝", BGColor.BLUE, "This is an important note."),
+        ("warning", "⚠️", BGColor.YELLOW, "This is a warning message."),
+        ("tip", "💡", BGColor.GREEN, "This is a helpful tip."),
     ],
 )
 def test_admonition_single_line(
     *,
     admonition_type: str,
     emoji: str,
-    color: Color,
+    background_color: BGColor,
     message: str,
     make_app: Callable[..., SphinxTestApp],
     tmp_path: Path,
@@ -744,7 +771,7 @@ def test_admonition_single_line(
     callout = UnoCallout(
         text=message,
         icon=Emoji(emoji=emoji),
-        color=color,
+        color=background_color,
     )
 
     expected_objects: list[NotionObject[Any]] = [
@@ -761,17 +788,17 @@ def test_admonition_single_line(
 
 
 @pytest.mark.parametrize(
-    argnames=("admonition_type", "emoji", "color"),
+    argnames=("admonition_type", "emoji", "background_color"),
     argvalues=[
-        ("note", "📝", Color.BLUE),
-        ("warning", "⚠️", Color.YELLOW),
-        ("tip", "💡", Color.GREEN),
+        ("note", "📝", BGColor.BLUE),
+        ("warning", "⚠️", BGColor.YELLOW),
+        ("tip", "💡", BGColor.GREEN),
     ],
 )
 def test_admonition_multiline(
     admonition_type: str,
     emoji: str,
-    color: Color,
+    background_color: BGColor,
     make_app: Callable[..., SphinxTestApp],
     tmp_path: Path,
 ) -> None:
@@ -786,7 +813,11 @@ def test_admonition_multiline(
 
            This is the second paragraph that should be nested.
     """
-    callout = UnoCallout(text="", icon=Emoji(emoji=emoji), color=color)
+    callout = UnoCallout(
+        text="",
+        icon=Emoji(emoji=emoji),
+        color=background_color,
+    )
     callout.rich_text = text(
         text=f"This is the first paragraph of the {admonition_type}."
     )
@@ -827,7 +858,7 @@ def test_admonition_with_code_block(
            The code above demonstrates a simple function.
     """
 
-    callout = UnoCallout(text="", icon=Emoji(emoji="📝"), color=Color.BLUE)
+    callout = UnoCallout(text="", icon=Emoji(emoji="📝"), color=BGColor.BLUE)
     callout.rich_text = text(text="This note contains a code example.")
 
     nested_code_block = _create_code_block_without_annotations(
@@ -871,7 +902,7 @@ def test_admonition_with_code_block_first(
            This paragraph comes after the code block.
     """
 
-    callout = UnoCallout(text="", icon=Emoji(emoji="📝"), color=Color.BLUE)
+    callout = UnoCallout(text="", icon=Emoji(emoji="📝"), color=BGColor.BLUE)
     callout.rich_text = text(text="")
 
     nested_code_block = _create_code_block_without_annotations(
@@ -911,7 +942,7 @@ def test_admonition_with_bullet_points(
            * B
     """
 
-    callout = UnoCallout(text="", icon=Emoji(emoji="📝"), color=Color.BLUE)
+    callout = UnoCallout(text="", icon=Emoji(emoji="📝"), color=BGColor.BLUE)
     callout.rich_text = text(
         text="This is an important note that demonstrates the note "
         "admonition\nsupport."
@@ -1031,3 +1062,108 @@ def test_collapse_block(
         tmp_path=tmp_path,
         extensions=("sphinx_notion", "sphinx_toolbox.collapse"),
     )
+
+
+def test_simple_table(
+    make_app: Callable[..., SphinxTestApp],
+    tmp_path: Path,
+) -> None:
+    """
+    Simple rST table converts to Notion Table block.
+    """
+    rst_content = """
+        +----------+----------+
+        | Header 1 | Header 2 |
+        +==========+==========+
+        | Cell 1   | Cell 2   |
+        +----------+----------+
+        | Cell 3   | Cell 4   |
+        |          |          |
+        | Cell 3   | Cell 4   |
+        +----------+----------+
+    """
+
+    table = UnoTable(n_rows=3, n_cols=2, header_row=True)
+    # Header row
+    table[0, 0] = text(text="Header 1")
+    table[0, 1] = text(text="Header 2")
+    # First data row
+    table[1, 0] = text(text="Cell 1")
+    table[1, 1] = text(text="Cell 2")
+    # Second data row
+    table[2, 0] = text(text="Cell 3\n\nCell 3")
+    table[2, 1] = text(text="Cell 4\n\nCell 4")
+
+    expected_objects: list[NotionObject[Any]] = [table]
+
+    _assert_rst_converts_to_notion_objects(
+        rst_content=rst_content,
+        expected_objects=expected_objects,
+        make_app=make_app,
+        tmp_path=tmp_path,
+    )
+
+
+def test_table_without_header_row(
+    make_app: Callable[..., SphinxTestApp],
+    tmp_path: Path,
+) -> None:
+    """
+    Table without a heading row converts to Notion Table block with
+    header_row=False.
+    """
+    rst_content = """
+        +--------+--------+
+        | Cell 1 | Cell 2 |
+        +--------+--------+
+        | Cell 3 | Cell 4 |
+        +--------+--------+
+    """
+    table = UnoTable(n_rows=2, n_cols=2, header_row=False)
+    table[0, 0] = text(text="Cell 1")
+    table[0, 1] = text(text="Cell 2")
+    table[1, 0] = text(text="Cell 3")
+    table[1, 1] = text(text="Cell 4")
+
+    expected_objects: list[NotionObject[Any]] = [table]
+
+    _assert_rst_converts_to_notion_objects(
+        rst_content=rst_content,
+        expected_objects=expected_objects,
+        make_app=make_app,
+        tmp_path=tmp_path,
+    )
+
+
+def test_table_inline_formatting(
+    make_app: Callable[..., SphinxTestApp],
+    tmp_path: Path,
+) -> None:
+    """
+    Table headers and cells with inline formatting (bold, italic, code) convert
+    to Notion Table with rich text in header and cells.
+    """
+    rst_content = """
+        +----------------------+----------------------+
+        | **Header Bold**      | *Header Italic*      |
+        +======================+======================+
+        | ``cell code``        | Normal cell          |
+        +----------------------+----------------------+
+    """
+
+    table = UnoTable(n_rows=2, n_cols=2, header_row=True)
+
+    table[0, 0] = text(text="Header Bold", bold=True)
+    table[0, 1] = text(text="Header Italic", italic=True)
+
+    table[1, 0] = text(text="cell code", code=True)
+    table[1, 1] = text(text="Normal cell")
+
+    expected_objects: list[NotionObject[Any]] = [table]
+
+    _assert_rst_converts_to_notion_objects(
+        rst_content=rst_content,
+        expected_objects=expected_objects,
+        make_app=make_app,
+        tmp_path=tmp_path,
+    )
